"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const axios_1 = __importDefault(require("axios"));
const homebridge_1 = require("homebridge");
/*
 * IMPORTANT NOTICE
 *
 * One thing you need to take care of is, that you never ever ever import anything directly from the "homebridge" module (or the "hap-nodejs" module).
 * The above import block may seem like, that we do exactly that, but actually those imports are only used for types and interfaces
 * and will disappear once the code is compiled to Javascript.
 * In fact you can check that by running `npm run build` and opening the compiled Javascript file in the `dist` folder.
 * You will notice that the file does not contain a `... = require("homebridge");` statement anywhere in the code.
 *
 * The contents of the above import statement MUST ONLY be used for type annotation or accessing things like CONST ENUMS,
 * which is a special case as they get replaced by the actual value and do not remain as a reference in the compiled code.
 * Meaning normal enums are bad, const enums can be used.
 *
 * You MUST NOT import anything else which remains as a reference in the code, as this will result in
 * a `... = require("homebridge");` to be compiled into the final Javascript code.
 * This typically leads to unexpected behavior at runtime, as in many cases it won't be able to find the module
 * or will import another instance of homebridge causing collisions.
 *
 * To mitigate this the {@link API | Homebridge API} exposes the whole suite of HAP-NodeJS inside the `hap` property
 * of the api object, which can be acquired for example in the initializer function. This reference can be stored
 * like this for example and used to access all exported variables and classes from HAP-NodeJS.
 */
let hap;
class LightController {
    constructor(log, config, api) {
        this._log = log;
        this._name = config.name;
        this._onUrl = config.onUrl;
        this._offUrl = config.offUrl;
        this._statusUrl = config.statusUrl;
        this._lightbulbService = new hap.Service.Lightbulb(this._name);
        this._lightbulbService.getCharacteristic(hap.Characteristic.On)
            .on("get" /* GET */, this.handleOnGet.bind(this))
            .on("set" /* SET */, this.handleOnSet.bind(this));
        this._informationService = new hap.Service.AccessoryInformation()
            .setCharacteristic(hap.Characteristic.Manufacturer, "Dirk-Jan")
            .setCharacteristic(hap.Characteristic.Model, "Light Controller")
            .setCharacteristic(hap.Characteristic.SerialNumber, ":)");
        log.info("Switch finished initializing!");
    }
    /*
     * This method is optional to implement. It is called when HomeKit ask to identify the accessory.
     * Typical this only ever happens at the pairing process.
     */
    identify() {
        this._log("Identify!");
    }
    /*
     * This method is called directly after creation of this instance.
     * It should return all services which should be added to the accessory.
     */
    getServices() {
        return [
            this._informationService,
            this._lightbulbService,
        ];
    }
    async handleOnGet(callback) {
        this._log.debug('Triggered GET On');
        try {
            let result = await axios_1.default.get(this._statusUrl);
            this._lightbulbService.getCharacteristic(homebridge_1.Characteristic.On).updateValue(result.data);
            callback(undefined, result.data);
        }
        catch (exception) {
        }
        callback(undefined, undefined);
    }
    async handleOnSet(value, callback) {
        this._log.debug('Triggered SET On:', value);
        let url = value === true ? this._onUrl : this._offUrl;
        try {
            await axios_1.default.post(url, {});
        }
        catch (exception) {
        }
        callback(null);
    }
}
module.exports = (api) => {
    hap = api.hap;
    api.registerAccessory("LightController", LightController);
};
//# sourceMappingURL=accessory.js.map